<?php
/**
 * contains static functions for HTML-Operations
 *
 * @author Schoenmann Guenter
 * @version 1.0.0.0
 * @license:
 */
class inoplugs_html extends inoplugs_object
{
	public function __construct(inoplugs_version $my_version = null, inoplugs_version $requ_version = null)
	{
		parent::__construct($my_version, $requ_version);
	}
	
	/**
	 *	Removes the first occurence resp. the last occurence of the specified tags,
	 *	if NO corresponding opening resp. closing tag is found.
	 *	e.g.    "</p>" is removed from the beginning, if no "<p>" is found before,
	 *			"<p>" is removed from the end, if no "</p>" is found after.
	 *
	 * @param string $string		string to remove tags from
	 * @param array $tags			tags, that shall be checked
	 * @return string			the string with the removed tags
	 */
	static public function html_remove_tags_unpaired($string, &$tags = array())
	{
		if(!is_array($tags) || (count($tags) == 0))
		{
			return $string;
		}

		foreach ($tags as &$tag)
		{
					//	check missing open tag
			$cl = stripos($string, "</$tag");
			if($cl !== false)
			{
				$op = stripos($string, "<$tag");
				if($op === false)
				{
					$op = $cl + 10;		//	set behind closing to simulate
				}
				if($cl < $op)
				{
					$string = self::html_remove_tag_at_pos($string, $cl);
				}
			}
					//	check missing closing tag
			$op = strripos($string, "<$tag");
			if($op !== false)
			{
				$cl = strripos($string, "</$tag");
				if($cl === false)
				{
					$cl = $op - 10;		//	set before closing to simulate
				}
				if($cl < $op)
				{
					$string = self::html_remove_tag_at_pos($string, $op);
				}
			}
		}
		unset ($tag);

		return $string;
	}

	/**
	 *	Gets a string and removes the complete tag. The position $start must point
	 *	to <. Everything up to > is removed. Only this tag is removed. If $start does not
	 *  point to <, the string is not changed.
	 *
	 * @param string $string		string, where to remove the tag from
	 * @param int $start			position, where to start from
	 * @return string				the string without the tag
	 */
	static public function html_remove_tag_at_pos($string, $start)
	{
		if(is_null($string) || (!isset($string)) || (!is_string($string)))
			return $string;
		if(!is_numeric($start))
			return $string;
		if($start < 0)
			return $string;

		$e = strlen($string);
		if($start >= $e)
			return $string;

		if($string[$start] != '<')
			return $string;

		$c = strpos($string, '>', $start);

		if($c === false)
			return $string;

		$s1 = "";
		$s2 = "";

		if($start > 0)
			$s1 = substr($string, 0, $start);

		$s2 = substr($string, $c + 1);
		if($s2 === false)
			$s2 = "";

		return $s1.$s2;
	}

	/**
	 *	Replaces the Hexnotations &#8220;, &#8221;, &#8216;, &#8217; to " resp. '
	 *	and returns a copy.
	 *
	 *	&#8242 is the minutesign after a number
	 *	&#8243 is produced by WP for " - *	it represents the second or inches sign after a number.
	 *
	 *	see also http://www.dwheeler.com/essays/quotes-in-html.html
	 *			 http://thewordpresswarrior.com/784/highlighting-code-and-removing-curly-quotes-smart-quotes
	 *
	 * @param string $string		string, where quotationmarks in hex are converted
	 *								to " or ' for normal stringoperations
	 * @return string		the string with the replaces characters
	 */
	static public function html_quots_decode($string)
	{
		$search = array('&#8220;', '&#8221;', '&#8216;', '&#8217;', '&#8242;', '&#8243;');
		$replace = array("\"", "\"", "'", "'", "'", "\"");
		return str_replace($search, $replace, $string);
	}

	/**
	 *	Returns the opening tag appended with the class:
	 *		<tag class="...">
	 *
	 * @param string $tag			HTML-tag
	 * @param string $class			string for the class
	 * @param bool $addclosingchar	true, when > shall be added (if not bool -> true
	 * @return string		the requested tag
	 */
	static public function &html_addtag_class_open($tag, $class, $addclosingchar=true)
	{
		$out = "<$tag";
		$c = trim($class);
		if($c != '')
			$out .= " class=\"$c\"";

		if(!is_bool($addclosingchar))
			$addclosingchar = true;

		if($addclosingchar)
			$out .= '>';

		return $out;
	}

	/**
	 *	Returns the closing tag:
	 *		</tag>
	 *
	 * @param string $tag			HTML-tag
	 * @return string		the requested tag
	 */
	static public function html_addtag_close($tag)
	{
		return "</$tag>";
	}

	/**
	 *	Returns a HTML-Commentstring:
	 *		<!--  .....  -->
	 *
	 * @param string $comment		the comment to include
	 * @param bool $newline			true -> add newline (if not bool -> false)
	 * @return string		the requested comment
	 */
	static public function &html_add_comment($comment, $newline = true)
	{
		$o = "<!-- $comment -->";
		if(!is_bool($newline))
			$newline = false;

		if($newline)
		{
			$o .= "\n";
		}
		return $o;
	}
}
?>
